/// <reference types="greensock" />
/// <reference types="preloadjs" />
/// <reference types="soundjs" />
export declare class ElearningPlayerBridge {
    static ON_READY: string;
    static ON_LOAD_PROGRESS: string;
    static ON_SUBTITLE: string;
    static ON_RESUME: string;
    static ON_PAUSE: string;
    static ON_SOUND_VOLUME_CHANGE: string;
    static ON_SOUND_STATE_CHANGE: string;
    static ON_SOUND_DESTROY: string;
    /**
    * @property player
    * @type {any}
    * @public
    */
    player: any;
    /**
    * @property timeline
    * @type {TimelineLite}
    * @public
    */
    timeline: TimelineLite;
    /**
    * @property playing
    * @type {boolean}
    * @public
    */
    playing: boolean;
    /**
    * @property _manifest
    * @type {string[]}
    * @private
    */
    private _manifest;
    /**
    * @property _sound
    * @type {createjs.AbstractSoundInstance}
    * @public
    */
    private _sound;
    /**
    * @property _subtitle
    * @type {string}
    * @public
    */
    _subtitle: string;
    /**
    * @property preload
    * @type {createjs.LoadQueue}
    * @public
    */
    preload: createjs.LoadQueue;
    /**
    * @property events
    * @type {any[]}
    * @public
    */
    events: any;
    /**
    * @property volume
    * @type {number}
    * @public
    */
    volume: number;
    constructor(assetsManifest?: string[]);
    /**
     * Start assets loading (TODO: add more initializations)
     */
    start: () => void;
    init: () => void;
    private updateTimelineInstance;
    sound: createjs.AbstractSoundInstance;
    subtitle: string;
    /**
     * Play sounds based on id
     */
    playSound: (id: string) => void;
    /**
     * Play sounds based on id
     */
    setSubtitle: (value: string) => void;
    /**
     * Must be used to define the page custom code;
     * Users must override this method or listen to this event;
     */
    protected onReady: () => void;
    /**
     * Page status toggle
     */
    togglePlayPause: () => void;
    /**
     * Toggle volume
     */
    toggleVolume: () => void;
    /**
     * Execute resume on animation instances (TimelineLite), sound instances (SoundJS), change page status state;
     */
    resume: () => void;
    /**
     * Execute pause on animation instances (TimelineLite), sound instances (SoundJS), change page status state;
     */
    pause: () => void;
    /**
     * Clean up;
     */
    kill(): void;
    /**
     * Page assets loading;
     */
    load: () => void;
    loadAnother: () => void;
    handleFileLoad: (event: any) => void;
    /**
     * Inform player about overall progress;
     */
    handleOverallProgress: (event: any) => void;
    handleFileError(event: any): void;
    manifest: string[];
    addEventListener: (event: string, callback: Function) => void;
    removeEventListener: (event: string, callback: Function) => void;
    dispatchEventWith: (event: string, details?: any) => void;
}
