"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var EventDispatcher = /** @class */ (function () {
    function EventDispatcher() {
        this.events = {};
    }
    EventDispatcher.prototype.addEventListener = function (event, callback) {
        // Check if the callback is not a function
        if (typeof callback !== 'function') {
            console.error("The listener callback must be a function, the given type is " + typeof callback);
            return;
        }
        // Check if the event is not a string
        if (typeof event !== 'string') {
            console.error("The event name must be a string, the given type is " + typeof event);
            return;
        }
        // Create the event if not exists
        if (this.events[event] === undefined) {
            this.events[event] = { listeners: [] };
        }
        this.events[event].listeners.push(callback);
    };
    EventDispatcher.prototype.removeEventListener = function (event, callback) {
        // Check if this event not exists
        if (this.events[event] === undefined) {
            console.error("This event: " + event + " does not exist");
            return;
        }
        this.events[event].listeners = this.events[event].listeners.filter(function (listener) {
            return listener.toString() !== callback.toString();
        });
    };
    EventDispatcher.prototype.dispatchEventWith = function (event, details) {
        // Check if this event not exists
        if (this.events[event] === undefined) {
            console.error("This event: " + event + " does not exist");
            return;
        }
        this.events[event].listeners.forEach(function (listener) {
            listener(details);
        });
    };
    return EventDispatcher;
}());
exports.EventDispatcher = EventDispatcher;
